==> v0.3.2.tar.gz: staticwebsitejovian/web/cv.php <==
<!DOCTYPE html>
<html lang="fr">

<?php
    $title = "CV";
    include("include/head.php");
?>

<body>
    <!-- Navbar -->
    <?php
        include("include/navbar.php")
    ?>

    <!-- Content -->
    <main role="main" class="container">
        <div class="focus-center">
            <h1>
                CV
            </h1>
            <img src="https://img.icons8.com/color/96/000000/parse-from-clipboard.png" alt="cv flat icon">
            <h2>
                Ingénieur en informatique
            </h2>
            <div class="row">
                <div class="col-12 lead">Diplômé de l'École Centrale de Nantes</div>
                <div class="col-12">
                    <img src="include/images/logoCN.png" class="mx-auto" alt="Logo Centrale Nantes">
                </div>
            </div>
            <a href="download/CV_Jovian_Hersemeule_2020.pdf" type="button" class="btn btn-success btn-lg">
                Télécharger
                <img src="include/icon/pdf.svg" alt="PDF">
            </a>
        </div>
        <h3>
            <img src="https://img.icons8.com/color/50/000000/student-male.png" alt="v ">
            Formation
        </h3>
        <div class="row">

            <!-- Centrale -->
            <div class="col-3">
                2017 - 2020
            </div>
            <div class="col-9">
                <b>École Centrale</b> – <span class="city">Nantes</span>
                <br/>
                Diplôme d'ingénieur
                <br/>
                Filière généraliste par alternance
                <br/>
                Option informatique spécialité génie informatique
            </div>

            <!-- Chateaubriand -->
            <div class="col-3">
                2015 - 2017
            </div>
            <div class="col-9">
                <b>Lycée Chateaubriand</b> – <span class="city">Rennes</span>
                <br/>
                Classe Préparatoire aux Grandes Écoles
                <br/>
                Filière MPI (Maths, Physique, Informatique)
                <br/>
                Option informatique théorique
            </div>

            <!-- Réaumur -->
            <div class="col-3">
                2013 - 2015
            </div>
            <div class="col-9">
                <b>Lycée Réaumur</b> – <span class="city">Laval</span>
                <br/>
                Bac général
                <br/>
                Filière SSI (Scientifique spécialité Sciences de l'Ingénieur)
            </div>
        </div>
        <h3>
            <img src="https://img.icons8.com/color/48/000000/compass.png" alt="v ">
            Expériences
        </h3>
        <div class="row">
            <div class="col-lg-12 col-xl-6">
                <h4>Professionnelles</h4>

                <!-- Viaccess France -->
                <div class="row">
                    <div class="col-3">
                        2017 - 2020
                    </div>
                    <div class="col-9">
                        <b>Viaccess Orca</b> – <span class="city">Cesson Sévigné</span>
                        <br/>
                        Développeur dans l'équipe outil
                        <br/>
                        Apprentissage en alternance
                        <br/>
                        Développement d'une application web de suivi de processus
                    </div>
                </div>

                <!-- Viaccess Finland -->
                <div class="row">
                    <div class="col-3">
                        mai - août 2019
                    </div>
                    <div class="col-9">
                        <b>Viaccess Orca Finland</b> – <span class="city">Tampere</span> – <em>Finlande</em>
                        <br/>
                        Développeur dans l'équipe Android
                        <br/>
                        Développement d'application mobile
                        <br/>
                        Réinstallation et modernisation d'un serveur d'intégration continue
                    </div>
                </div>

            </div>

            <div class="col-lg-12 col-xl-6">

                <h4>Scolaires</h4>

                <!-- Projet de Centrale -->
                <div class="row">
                    <div class="col-3">
                        2019 - 2020
                    </div>
                    <div class="col-9">
                        <b>Conception d'un jeu-vidéo</b>
                        <br/>
                        Projet professionnalisant
                        <br/>
                        Développement du jeu et administration des outils de projet
                        <br/>
                        En équipe avec une graphiste et un responsable de projet
                    </div>
                </div>

                <!-- TIPE -->
                <div class="row">
                    <div class="col-3">
                        2016 - 2017
                    </div>
                    <div class="col-9">
                        <b>Conception d'IA</b>
                        <br/>
                        Projet de concours
                        <br/>
                        Développement d'Intelligences Artificielles (IA) sur le jeu de stratégie Quoridor
                    </div>
                </div>

            </div>
        </div>

        <h3>
            <img src="https://img.icons8.com/color/48/000000/development-skill.png" alt="v ">
            Compétences
        </h3>

        <div class="row">
            <div class="col-lg-12 col-xl-4">
                <h4>Langues</h4>

                <div class="row">
                    <b class="col-4">
                        Français
                    </b>
                    <div class="col-8">
                        Langue maternelle
                    </div>

                    <b class="col-4">
                        Anglais
                    </b>
                    <div class="col-8">
                        Courant
                        <br/>
                        score <strong>920</strong> au TOEIC
                    </div>

                    <b class="col-4">
                        Allemand
                    </b>
                    <div class="col-8">
                        Intermédiaire
                        <br/>
                        équivalent A2
                    </div>

                    <br/>
                </div>
            </div>

            <div class="col-lg-12 col-xl-8">

                <h4>Informatique</h4>

                <div class="row">
                    <b class="col-4">
                        Langages
                    </b>
                    <div class="col-8">
                        C++ Python Java Groovy Kotlin Haskell
                    </div>

                    <b class="col-4">
                        GNU/Linux
                    </b>
                    <div class="col-8">
                        SSH Shell Ubuntu APT Systemd QEMU/KVM
                    </div>

                    <b class="col-4">
                        Outils
                    </b>
                    <div class="col-8">
                        Git Vim Jenkins IntelliJ GitLab
                    </div>

                    <b class="col-4">
                        Données
                    </b>
                    <div class="col-8">
                        SQL PostgreSQL Modélisation
                    </div>

                    <b class="col-4">
                        Web
                    </b>
                    <div class="col-8">
                        Bootstrap Angular HTML
                    </div>

                    <b class="col-4">
                        Méthodes
                    </b>
                    <div class="col-8">
                        UML Kanban Scrum
                    </div>

                    <b class="col-4">
                        Administration de systèmes
                    </b>
                    <div class="col-8">
                        Sécurité Réseau WakeOnLan Cron
                    </div>
                </div>
            </div>
        </div>
        <h3>
            <img src="https://img.icons8.com/color/48/000000/treble-clef.png" alt="v ">
            Intérêts
        </h3>

        <div class="row">
            <div class="col-md-12 col-lg-6 col-xl-4">

                <h4>Engagement associatif</h4>
                Bénévole à Ingénieurs Sans Frontières
                <br/>
                - groupe local de Nantes (3 ans)
                <br/>
                - équipe systèmes d'information de la coordination nationale (depuis mai 2020)
            </div>

            <div class="col-md-12 col-lg-6 col-xl-4">

                <h4>Voyages</h4>
                Stage international : <em>Finlande</em>
                <br/>
                Touristiques : <em>Maroc, Angleterre, Italie, Espagne</em>
                <br/>
                Hébergé chez l'habitant : <em>Pays de Galles</em>
                <br/>
                Échanges et jumelage : <em>Allemagne</em>
            </div>

            <div class="col-md-12 col-lg-6 col-xl-2">

                <h4>Sport</h4>
                Vélo
                <br/>
                Course à pieds
                <br/>
                Badmindton
            </div>

            <div class="col-md-12 col-lg-6 col-xl-2">

                <h4>Musique</h4>
                Clarinettiste en orchestre d'harmonie
                <br/>
                Débutant en guitare
            </div>
        </div>

    </main>

    <!-- Footer -->
    <?php
        include("include/footer.php")
    ?>

    <!-- Scripts -->
    <script src="https://code.jquery.com/jquery-3.3.1.slim.min.js"
            integrity="sha384-q8i/X+965DzO0rT7abK41JStQIAqVgRVzpbzo5smXKp4YfRvH+8abtTE1Pi6jizo"
            crossorigin="anonymous"></script>
    <script src="include/js/bootstrap.js"></script>
</body>
</html>

==> v0.3.3.tar.gz: staticwebsitejovian/web/cv.php <==
<!DOCTYPE html>
<html lang="fr">

<?php
    $title = "CV";
    include("include/head.php");
?>

<body>
    <!-- Navbar -->
    <?php
        include("include/navbar.php")
    ?>

    <!-- Content -->
    <main role="main" class="container">
        <div class="focus-center">
            <h1>
                CV
            </h1>
            <img src="https://img.icons8.com/color/96/000000/parse-from-clipboard.png" alt="cv flat icon">
            <h2>
                Ingénieur en informatique
            </h2>
            <div class="row">
                <div class="col-lg-12 col-xl-6 lead">Diplômé de l'École Centrale de Nantes</div>
                <div class="col-lg-12 col-xl-6 lead">Ingénieur logiciel chez Qarnot Computing</div>
                <div class="col-lg-12 col-xl-6">
                    <img src="include/images/logoCN.png" class="mx-auto img-fluid m-3" alt="Logo Centrale Nantes">
                </div>
                <div class="col-lg-12 col-xl-6">
                    <img src="include/images/logoQarnot.png" class="mx-auto img-fluid m-4" alt="Logo Qarnot">
                </div>
            </div>
            <a href="download/CV_Jovian_Hersemeule.pdf" type="button" class="btn btn-success btn-lg">
                Télécharger
                <img src="include/icon/pdf.svg" alt="PDF">
            </a>
        </div>
        <h3>
            <img src="https://img.icons8.com/color/50/000000/student-male.png" alt="v ">
            Formation
        </h3>
        <div class="row">

            <!-- Centrale -->
            <div class="col-3">
                2017 - 2020
            </div>
            <div class="col-9">
                <b>École Centrale</b> – <span class="city">Nantes</span>
                <br/>
                Diplôme d'ingénieur
                <br/>
                Filière généraliste par alternance
                <br/>
                Option informatique spécialité génie informatique
            </div>

            <!-- Chateaubriand -->
            <div class="col-3">
                2015 - 2017
            </div>
            <div class="col-9">
                <b>Lycée Chateaubriand</b> – <span class="city">Rennes</span>
                <br/>
                Classe Préparatoire aux Grandes Écoles
                <br/>
                Filière MPI (Maths, Physique, Informatique)
                <br/>
                Option informatique théorique
            </div>

            <!-- Réaumur -->
            <div class="col-3">
                2013 - 2015
            </div>
            <div class="col-9">
                <b>Lycée Réaumur</b> – <span class="city">Laval</span>
                <br/>
                Bac général
                <br/>
                Filière SSI (Scientifique spécialité Sciences de l'Ingénieur)
            </div>
        </div>
        <h3>
            <img src="https://img.icons8.com/color/48/000000/compass.png" alt="v ">
            Expériences
        </h3>
        <div class="row">
            <div class="col-lg-12 col-xl-6">
                <h4>Professionnelles</h4>

                <!-- Qarnot -->
                <div class="row">
                    <div class="col-3">
                        2021 -
                    </div>
                    <div class="col-9">
                        <b>Qarnot Computing</b> – <span class="city">Montrouge</span>
                        <br/>
                        Développeur logiciel infrastructure distribuée
                        <br/>
                        Développement en Dotnet Core sur la plateforme de calcul haute performance décentralisée sur des radiateurs-ordinateurs
                    </div>
                </div>

                <!-- Viaccess France -->
                <div class="row">
                    <div class="col-3">
                        2017 - 2020
                    </div>
                    <div class="col-9">
                        <b>Viaccess Orca</b> – <span class="city">Cesson Sévigné</span>
                        <br/>
                        Développeur dans l'équipe outil
                        <br/>
                        Apprentissage en alternance
                        <br/>
                        Développement d'une application web de suivi de processus
                    </div>
                </div>

                <!-- Viaccess Finland -->
                <div class="row">
                    <div class="col-3">
                        mai - août 2019
                    </div>
                    <div class="col-9">
                        <b>Viaccess Orca Finland</b> – <span class="city">Tampere</span> – <em>Finlande</em>
                        <br/>
                        Développeur dans l'équipe Android
                        <br/>
                        Développement d'application mobile
                        <br/>
                        Réinstallation et modernisation d'un serveur d'intégration continue
                    </div>
                </div>

            </div>

            <div class="col-lg-12 col-xl-6">

                <h4>Scolaires</h4>

                <!-- Projet de Centrale -->
                <div class="row">
                    <div class="col-3">
                        2019 - 2020
                    </div>
                    <div class="col-9">
                        <b>Conception d'un jeu-vidéo</b>
                        <br/>
                        Projet professionnalisant
                        <br/>
                        Développement du jeu et administration des outils de projet
                        <br/>
                        En équipe avec une graphiste et un responsable de projet
                    </div>
                </div>

                <!-- TIPE -->
                <div class="row">
                    <div class="col-3">
                        2016 - 2017
                    </div>
                    <div class="col-9">
                        <b>Conception d'IA</b>
                        <br/>
                        Projet de concours
                        <br/>
                        Développement d'Intelligences Artificielles (IA) sur le jeu de stratégie Quoridor
                    </div>
                </div>

            </div>
        </div>

        <h3>
            <img src="https://img.icons8.com/color/48/000000/development-skill.png" alt="v ">
            Compétences
        </h3>

        <div class="row">
            <div class="col-lg-12 col-xl-4">
                <h4>Langues</h4>

                <div class="row">
                    <b class="col-4">
                        Français
                    </b>
                    <div class="col-8">
                        Langue maternelle
                    </div>

                    <b class="col-4">
                        Anglais
                    </b>
                    <div class="col-8">
                        Courant
                        <br/>
                        score <strong>920</strong> au TOEIC
                    </div>

                    <b class="col-4">
                        Allemand
                    </b>
                    <div class="col-8">
                        Intermédiaire
                        <br/>
                        équivalent A2
                    </div>

                    <br/>
                </div>
            </div>

            <div class="col-lg-12 col-xl-8">

                <h4>Informatique</h4>

                <div class="row">
                    <b class="col-4">
                        Langages
                    </b>
                    <div class="col-8">
                        C# Dotnet C++ Python Java Groovy Kotlin
                    </div>

                    <b class="col-4">
                        GNU/Linux
                    </b>
                    <div class="col-8">
                        SSH Shell Ubuntu APT Systemd Docker QEMU/KVM
                    </div>

                    <b class="col-4">
                        Outils
                    </b>
                    <div class="col-8">
                        Git Vim Buildbot VSCode GitLab Jira
                    </div>

                    <b class="col-4">
                        Données
                    </b>
                    <div class="col-8">
                        SQL PostgreSQL Modélisation
                    </div>

                    <b class="col-4">
                        Web
                    </b>
                    <div class="col-8">
                        Bootstrap Angular HTML
                    </div>

                    <b class="col-4">
                        Méthodes
                    </b>
                    <div class="col-8">
                        UML Kanban Scrum
                    </div>

                    <b class="col-4">
                        Administration de systèmes
                    </b>
                    <div class="col-8">
                        Conteneurisation Sécurité Réseau
                    </div>
                </div>
            </div>
        </div>
        <h3>
            <img src="https://img.icons8.com/color/48/000000/treble-clef.png" alt="v ">
            Intérêts
        </h3>

        <div class="row">
            <div class="col-md-12 col-lg-6 col-xl-4">

                <h4>Engagement associatif</h4>
                Bénévole à Ingénieurs Sans Frontières
                <br/>
                - groupe local de Nantes (3 ans)
                <br/>
                - équipe systèmes d'information de la coordination nationale (depuis mai 2020)
            </div>

            <div class="col-md-12 col-lg-6 col-xl-4">

                <h4>Voyages</h4>
                Stage international : <em>Finlande</em>
                <br/>
                Touristiques : <em>Maroc, Angleterre, Italie, Espagne</em>
                <br/>
                Hébergé chez l'habitant : <em>Pays de Galles</em>
                <br/>
                Échanges et jumelage : <em>Allemagne</em>
            </div>

            <div class="col-md-12 col-lg-6 col-xl-2">

                <h4>Sport</h4>
                Vélo
                <br/>
                Course à pieds
                <br/>
                Badmindton
            </div>

            <div class="col-md-12 col-lg-6 col-xl-2">

                <h4>Musique</h4>
                Clarinettiste en orchestre d'harmonie
                <br/>
                Débutant en guitare
            </div>
        </div>

    </main>

    <!-- Footer -->
    <?php
        include("include/footer.php")
    ?>

    <!-- Scripts -->
    <script src="https://code.jquery.com/jquery-3.3.1.slim.min.js"
            integrity="sha384-q8i/X+965DzO0rT7abK41JStQIAqVgRVzpbzo5smXKp4YfRvH+8abtTE1Pi6jizo"
            crossorigin="anonymous"></script>
    <script src="include/js/bootstrap.js"></script>
</body>
</html>
